@@ -201,7 +201,8 @@ class Connection():
         return stetament
 
     def __is_clause_table__(self, condition):
-        if not '.' in condition:
+        regex=re.compile('((([a-zA-Z]+\_?)+)\.)')
+        if not re.match(regex, condition):
             return True
         else:
             if not f"{self._table}." in condition:
